#! /bin/sh
# aside from this initial boilerplate, this is actually -*- scheme -*- code
main='(module-ref (resolve-module '\''(src xmlt)) '\'main')'
exec ${GUILE-guile} -l $0 -c "(apply $main (cdr (command-line)))" "$@"
!#
;;;; This file is part of XMLTools
;;;; Copyright (C) 2004 Sergey Poznyakoff
;;;;
;;;; XMLTools is free software; you can redistribute it and/or modify
;;;; it under the terms of the GNU General Public License as published by
;;;; the Free Software Foundation; either version 2 of the License, or
;;;; (at your option) any later version.
;;;;
;;;; XMLTools is distributed in the hope that it will be useful,
;;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;;; GNU General Public License for more details.
;;;;
;;;; You should have received a copy of the GNU General Public License
;;;; along with XMLTools; if not, write to the Free Software
;;;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
;;;;

;;; Tailor this statement to your needs if necessary.
;=GUILE_COMMENT=;(set! %load-path (cons "=GUILE_SITE=" %load-path))

;;; Main procedure
(define-module (src xmlt)
  :export (xmlt))

(use-modules (xmltools xmltrans)
	     (xmltools gamlet)
	     (xmltools dict)
	     (ice-9 format)
             (ice-9 rdelim)
	     (ice-9 getopt-long))


;;;; Executable module support
(define (xmlt:error . rest)
  (with-output-to-port
      (current-error-port)
    (lambda ()
      (for-each
       display
       rest)
      (newline))))

(define (usage)
  (display "usage: xmlt module [options]\n")
  (exit 0))

(define xmlt-module #f)

(define (get-module)
  (if (not xmlt-module)
      (set! xmlt-module (resolve-module '(src xmlt))))
  xmlt-module)
      
(define-macro (bound? name)
  `(and (module-defined? xmlt-module ',name)
	(procedure? ,name)))

(define (xmlt:load arglist)
  (module-use!
   (get-module)
   (resolve-interface (list 'xmltrans (string->symbol (car arglist)))))
  (if (bound? parse-command-line)
      (parse-command-line arglist)
      (cdr arglist)))

(define (xmlt:begin-processing)
  (and (bound? begin-processing)
       (begin-processing)))

(define (xmlt:end-processing)
  (and (bound? end-processing)
       (end-processing))
  (gamlet:flush)
  (exit 0))

(define (xmlt . args)
  ;; Initialize the stuff
  (gamlet:init)
  (gamlet:change-pp-delimiter #\{ #\})

  (cond
   ((= 0 (length args))
    (xmlt:error "Too few arguments")
    (exit 1))
   ((or (string=? (car args) "-h") (string=? (car args) "--help"))
    (usage))
   (else
    (let ((input-files (xmlt:load args)))
      (if (null? input-files)
	  (begin
	    (xmlt:error "Input files not specified")
	    (exit 1)))

      (xmlt:begin-processing)
      
      (for-each
       (lambda (x)
	 (if (not (xmltrans:parse-file x))
	     (exit 1))) ;; FIXME: gamlet files are not cleaned up
       input-files)

      (xmlt:end-processing)))))

(define main xmlt)

;;;; xmlt ends here